==> zio-aws-apigatewayv2_3-5.17.112.1-sources.jar: zio/aws/apigatewayv2/model/GetStageRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetStageRequest(apiId: __string, stageName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest = {
    import GetStageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .stageName(__string.unwrap(stageName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetStageRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetStageRequest.wrap(buildAwsValue())
}
object GetStageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetStageRequest =
      zio.aws.apigatewayv2.model.GetStageRequest(apiId, stageName)
    def apiId: __string
    def stageName: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getStageName: ZIO[Any, Nothing, __string] = ZIO.succeed(stageName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest
  ) extends zio.aws.apigatewayv2.model.GetStageRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val stageName: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.stageName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest
  ): zio.aws.apigatewayv2.model.GetStageRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-6.20.115.1-sources.jar: zio/aws/apigatewayv2/model/GetStageRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetStageRequest(apiId: __string, stageName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest = {
    import GetStageRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .stageName(stageName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetStageRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetStageRequest.wrap(buildAwsValue())
}
object GetStageRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetStageRequest =
      zio.aws.apigatewayv2.model.GetStageRequest(apiId, stageName)
    def apiId: __string
    def stageName: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getStageName: ZIO[Any, Nothing, __string] = ZIO.succeed(stageName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest
  ) extends zio.aws.apigatewayv2.model.GetStageRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val stageName: __string = impl.stageName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetStageRequest
  ): zio.aws.apigatewayv2.model.GetStageRequest.ReadOnly = new Wrapper(impl)
}
